@@ -25,7 +25,7 @@ def display_notification(command, return_code):
         notification = notify.Notification(command, description, icon)
         notification.show()
 
-def main():
+def run_command():
     if len(sys.argv) < 2:
         print 'Usage: naf <command_to_run>'
         sys.exit(1)
@@ -36,5 +36,11 @@ def main():
 
     sys.exit(return_code)
 
+def main():
+    try:
+        run_command()
+    except KeyboardInterrupt:
+        sys.exit("KeyboardInterrupt")
+
 if __name__ == '__main__':
     main()
